@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1301';
+our $VERSION = '0.1302';
 
 use Moo;
 use Music::Chord::Note;
@@ -255,7 +255,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1301
+version 0.1302
 
 =head1 SYNOPSIS
 
@@ -273,11 +273,18 @@ version 0.1301
 
   $chords = $mc->cadence(
     type    => 'half',
-    leading => 2,
     octave  => 0,
+    leading => 2,
   );
   # [['D','F','A'], ['G','B','D']]
 
+  $chords = $mc->cadence(
+    type      => 'imperfect',
+    octave    => 4,
+    inversion => { 1 => 1, 2 => 1 },
+  );
+  # [['B4','D4','G4'], ['E4','G4','C4']]
+
   $mc = Music::Cadence->new(
     key    => 'C#',
     octave => 5,
@@ -295,39 +302,22 @@ version 0.1301
   $chords = $mc->cadence;
   # [['Gs5','C5','Ds5'], ['Cs5','F5','Gs5','Cs6']]
 
-  $mc = Music::Cadence->new(
-    octave => 4,
-    format => 'midinum',
-  );
+  $mc = Music::Cadence->new( format => 'midinum' );
 
-  $chords = $mc->cadence;
+  $chords = $mc->cadence( octave => 4 );
   # [[67,71,62], [60,64,67,72]]
 
-  $mc = Music::Cadence->new(
-    octave => -1,
-    format => 'midinum',
-  );
-
-  $chords = $mc->cadence;
+  $chords = $mc->cadence( octave => -1 );
   # [[7,11,2], [0,4,7,12]]
 
-  $mc = Music::Cadence->new;
-
-  $chords = $mc->cadence(
-    octave    => 4,
-    type      => 'imperfect',
-    inversion => { 1 => 1, 2 => 1 },
-  );
-  # [['B4','D4','G4'], ['E4','G4','C4']]
-
   $mc = Music::Cadence->new( seven => 1 );
 
   $chords = $mc->cadence;
   # [['G','B','D','F'], ['C','E','G','A#','C']]
 
   $chords = $mc->cadence(
-    octave => 4,
     type   => 'evaded',
+    octave => 4,
   );
   # [['F4','G5','B5','D5'], ['E4','G4','A#4','C5']]
 
@@ -476,8 +466,8 @@ the third inversion and the second by the first inversion.
 
 =head1 SEE ALSO
 
-The F<eg/cadence>, F<t/01-methods.t> and F<t/02-methods.t> files in
-this distribution.
+The F<eg/cadence>, F<eg/synopsis>, F<t/01-methods.t> and
+F<t/02-methods.t> files in this distribution.
 
 L<Moo>
 
